[]: {{{1

    File        : README.md
    Maintainer  : Felix C. Stegerman <flx@obfusk.net>
    Date        : 2016-10-20

    Copyright   : Copyright (C) 2016  Felix C. Stegerman
    Version     : v0.0.1

[]: }}}1

<!-- badge? -->
[![Build Status](https://travis-ci.org/obfusk/obfusk.py.png)](https://travis-ci.org/obfusk/obfusk.py)

## Description

obfusk.py - functional programming (& other tools) library for python (2+3)

See `obfusk/*.py` for the code (with examples).

<!--

## Examples

...

-->

## Specs & Docs

```bash
$ python -mobfusk -v                # run tests
$ python -mcoverage run -m obfusk   # test coverage
$ python -mcoverage html            # generate html report
$ pydoc obfusk                      # view docs
```

## TODO

  * proper algebraic data types?
  * ...

## License

LGPLv3+ [1].

## References

[1] GNU Lesser General Public License, version 3
--- https://www.gnu.org/licenses/lgpl-3.0.html

[]: ! ( vim: set tw=70 sw=2 sts=2 et fdm=marker : )
